#!/usr/bin/env python3
import os
import csv
import datetime

regions = {}

alt_names = {
        "Czechia": ["Czech Republic"],
        "South Korea": ["Korea, South"],
        "United Kingdom": ["UK"],
        "Diamond Princess": ["Diamond Princess cruise ship"],
}

def translate_region(region):
    for orig, names in alt_names.items():
        for name in names:
            if region == name:
                return orig
    return region

fns = [fn for fn in os.listdir() if fn.endswith(".csv")]
fns.sort()

for fn in fns:
    month, day, year  = fn.partition('.')[0].split("-")
    d = datetime.date(int(year), int(month), int(day))
    first_line = True
    for line in csv.reader(open(fn, "r")):
        if first_line:
            if "FIPS" in line[0]:
                fips = True
            else:
                fips = False
            first_line = False
            continue

        if fips:
            # skip US because the data for US is a big inconsistent mess
            if line[3] == 'US': continue
            if line[2]:
                region = line[2]
            else:
                region = line[3]
            if not line[7]:
                confirmed = 0
            else:
                confirmed = int(line[7])
            if not line[8]:
                dead = 0
            else:
                dead = int(float(line[8]))
        else:
            # skip US because the data for US is a big inconsistent mess
            if line[1] == 'US': continue
            if line[0]:
                region = line[0]
            else:
                region = line[1]
            if not line[3]:
                confirmed = 0
            else:
                confirmed = int(line[3])
            if not line[4]:
                dead = 0
            else:
                dead = int(line[4])
        region = translate_region(region)

        if region not in regions:
            regions[region] = []

        regions[region].append({
            "confirmed": confirmed,
            "dead": dead,
            "day": d,
            })

import pprint
for name, dates in regions.items():
    # known typos
    if name in ["French Polynesia", "Diamond Princess", "Hebei", "Gansu", "Kazakhstan", "Serbia"]: continue
    # known cheater
    if name in ["Slovakia", "Quebec", "Iceland", "Germany"]: continue
    last_confirmed = None
    last_dead = None
    for date in dates:
        confirmed = date["confirmed"]
        dead = date["dead"]

        if last_confirmed is not None:
            if last_confirmed > confirmed:
                pass

        if last_dead is not None:
            if last_dead > dead:
                print(f'!! {name}')
#                pprint.pprint(regions[name])
                break

        last_confirmed = confirmed
        last_dead = dead

